Remote

Struct Remote 

pub struct Remote { /* private fields */ }
Registry of actors linked into this image and registered by way of crate::register_spawnable.

Implementations

Source

impl Remote

pub fn collect() -> Self

Construct a registry. Panics if there are conflicting registrations.

pub fn global() -> &'static Self

Return the process-wide remote spawn registry.

pub fn name_of<A: Actor>(&self) -> Option<&'static str>

Returns the name of the provided actor, if registered.

pub async fn gspawn( &self, proc: &Proc, actor_type: &str, actor_uid: Uid, params: Data, environment: Flattrs, ) -> Result<ActorAddr, Error>

Spawns the actor with the provided sender, actor uid, and serialized parameters. Returns an error if the actor is not registered, or if the actor’s spawn fails.

pub async fn gspawn_child( &self, proc: &Proc, parent: InstanceCell, actor_type: &str, actor_uid: Uid, params: Data, environment: Flattrs, ) -> Result<AnyActorHandle, Error>

Spawns the actor as a child of the provided parent. Returns an erased lifecycle handle.